*This dofile replicates the findings of "Externalities in International Tax Enforcement: Theory and Evidence" (December, 2020)


*** Creating ownership links for counterfactual ***
cd "/Users/ludvigwier/Dropbox/International tax enforcement/Paper/International tax enforcement - theory and evidence/Data"
use "/Users/ludvigwier/Dropbox/Skatteprojekter/Skat/ownershipstructure.dta", clear /* Loading ORBIS ownership data - data lists all Danish links to foreign companies*/

gen one=1
collapse (sum) one, by(country year) /*summarizing number of links pr. country*/
save collapsedownership, replace

*** Merge in effective tax rates from "The Missing Profits of Nations" -Main Table 2  ***

merge m:1 country using eff_tax_2015
drop _merge
replace eff_tax=eff_tax*100
gen Tax_diff_effective=15-eff_tax /*generating tax differential (Danish effective tax rate is 15% in 2015*/

*** Merge in statutory tax rates from KPMG corporate tax tables - Tax differential to Denmark (Tax_diff_statutory) already computed in the imported file***
merge 1:1 country year using KPMG

*** Append Transfer Price Correction data - Tax differential to Denmark effective and statutory already computed in the imported file (taxdiff_TP and taxdiff_TP_effective) ***
append using TPcorrections

*** Court data - Tax differential to Denmark effective and statutory already computed in the imported file (court_diff and court_diff_effective) ***
append using CourtCases

*** Dispute settlement data - Tax differential to Denmark (statutory) already computed in the imported file (MAP_diff) ***
append using MAPdata

*** Generating cumulative distributions ***
cumul Tax_diff_statutory [w=one], gen(call_stat) 
cumul Tax_diff_effective [w=one], gen(call_eff) 
cumul taxdiff_TP [w=TPc], gen(cTP) /* TPc=number of TP corrections*/
cumul taxdiff_TP_eff [w=TPc], gen(cTP_eff)
cumul MAP_diff [w=MAPc], gen(cMAP) /* MAPc=number of completed MAP cases*/
cumul court_diff [w=courtcases], gen(c_court)
cumul court_diff [w=courtcases_nonEU], gen(c_courtnomap)
cumul court_diff_eff [w=courtcases], gen(c_court_eff)
cumul court_diff_eff [w=courtcases_nonEU], gen(c_courtnomap_eff)

*** Creating main graphs ***
sort cTP call_stat
twoway line cTP taxdiff_TP if cTP!=., sort || line call Tax_diff_statutory if call_stat!=., sort

sort cTP call_stat cMAP
twoway line cTP taxdiff_TP if cTP!=., sort || line call Tax_diff_statutory if call_stat!=., sort || line cMAP MAP_diff if cMAP!=., sort

sort cTP call_stat c_court
twoway line cTP taxdiff_TP if cTP!=., sort || line call Tax_diff_statutory if call_stat!=., sort || line c_court court_diff if c_court!=., sort

sort cTP call_stat c_courtnomap
twoway line cTP taxdiff_TP if cTP!=., sort || line call Tax_diff_statutory if call_stat!=., sort || line c_courtnomap court_diff if c_courtnomap!=., sort


*** Replicating graphs using effective tax rates ***
sort cTP_eff call_eff
twoway line cTP_eff taxdiff_TP_eff if cTP_eff!=., sort || line call Tax_diff_eff if call_eff!=., sort

sort cTP_eff call_eff c_court_eff
twoway line cTP_eff taxdiff_TP_eff if cTP_eff!=., sort || line call_eff Tax_diff_eff if call_eff!=., sort || line c_court_eff court_diff_eff if c_court_eff!=., sort

sort cTP_eff call_eff c_courtnomap_eff
twoway line cTP_eff taxdiff_TP_eff if cTP_eff!=., sort || line call_eff Tax_diff_eff if call_eff!=., sort || line c_courtnomap_eff court_diff_eff if c_courtnomap_eff!=., sort



*** Regressions for reporting differential in figures with statutory tax rates ***
 reg taxdiff_TP [w=TPc], r
 reg Tax_diff_statutory [w=one], r
 reg MAP_diff, r
 reg court_diff, r
 reg court_diff if c_courtnomap!=., r


*** Regressions for reporting differential in figures with effective tax rates ***
 reg taxdiff_TP_eff [w=TPc], r
 reg Tax_diff_eff [w=one], r
 reg MAP_diff_eff, r
 reg court_diff_eff, r
 reg court_diff_eff if c_courtnomap_eff!=., r

 
*** Counterfactual created using FDI income ***
joinby country using "FDI income link"
destring totalfdiincome, ignore(",") replace
replace totalfdiincome=-totalfdiincome if totalfdiincome<0
replace totalfdiincome=round(totalfdiincome*100)
cumul Tax_diff_statutory [w=totalfdiincome], gen(call_fdiincomeweighted)

sort cTP call_stat
twoway line cTP taxdiff_TP if cTP!=., sort ||  line call_f Tax_diff_statutory if call_f!=., sort
 
reg Tax_diff_statutory [w=totalfdiincome], r
 
